#ifndef S9X_NETPLAY_H
#define S9X_NETPLAY_H

#include "defines.h"
#include "frend.h"
#include "misc.h"
#include "skins.h"

#define S9X_NETPLAY_PORT 6096

class s9x_NetPlay :     public s9x_Notepage
{
 private:
   fr_Checkbox		UseNetPlay;
   fr_Text		s9xServer; 
   fr_NumEntry		s9xPort;
   void			EventOccurred(fr_Event*e);
 public:
                        s9x_NetPlay(fr_Notebook*parent);
    void                SetToDefaults();
    void		Set9xVersion(float version);
    void                SiftArgs(fr_ArgList& L);
    void                CompileArgs(fr_ArgList& L);
};

#endif
